﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using Infragistics.Windows.DataPresenter;
using System.Collections.ObjectModel;
using Infragistics.Windows.DataPresenter.Calculations;

namespace FieldCalculationSettingsSample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            FieldLayout fieldLayout = new FieldLayout();
            fieldLayout.CalculationReferenceId = "DataItemsLayout";

            Field firstField = new Field("FirstField");
            fieldLayout.Fields.Add(firstField);

            Field secondField = new Field("SecondField");
            fieldLayout.Fields.Add(secondField);

            UnboundField thirdField = new UnboundField();
            thirdField.Name = "ThirdField";
            thirdField.Settings.EditAsType = typeof(double);
            FieldCalculationSettings thirdFieldFormula = new FieldCalculationSettings();
            thirdFieldFormula.Formula = "[FirstField] + [SecondField]";
            thirdField.CalculationSettings = thirdFieldFormula;
            fieldLayout.Fields.Add(thirdField);

            UnboundField fourthField = new UnboundField();
            fourthField.Name = "FourthField";
            fourthField.Settings.EditAsType = typeof(double);
            FieldCalculationSettings fourthFieldFormula = new FieldCalculationSettings();
            fourthFieldFormula.Formula = "[FirstField] - [SecondField]";
            fourthField.CalculationSettings = fourthFieldFormula;
            fieldLayout.Fields.Add(fourthField);

            this.dataGrid.FieldLayouts.Add(fieldLayout);

            ObservableCollection<DataItem> dataItems = new ObservableCollection<DataItem>
            {
                new DataItem(10.0, 14.0),
                new DataItem(2.0, 5.0),
                new DataItem(25.0, 13.0)
            };

            this.dataGrid.DataSource = dataItems;
        }
    }

    public class DataItem : INotifyPropertyChanged
    {
        private double _firstField;
        private double _secondField;

        public double FirstField
        {
            get
            {
                return this._firstField;
            }
            set
            {
                this._firstField = value;
                this.RaisePropertyChanged("FirstField");
            }
        }

        public double SecondField
        {
            get
            {
                return this._secondField;
            }
            set
            {
                this._secondField = value;
                this.RaisePropertyChanged("SecondField");
            }
        }

        public DataItem(double firstValue, double secondValue)
        {
            this._firstField = firstValue;
            this._secondField = secondValue;
        }

        private void RaisePropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        #endregion
    }
}
